@@ -13,7 +13,8 @@ from .. import exceptions
 
 
 def check_required_fields(
-    dataset: Union[str, Path, pd.DataFrame, dd.DataFrame], required_fields: List[str],
+    dataset: Union[str, Path, pd.DataFrame, dd.DataFrame],
+    required_fields: List[str],
 ) -> Optional[exceptions.MissingDataError]:
     # Handle dataset provided as string or path
     if isinstance(dataset, (str, Path)):
